## TL;DR

`raydl` is a library of utilities to help you deal with the deep learning in PyTorch.

### Features

- Minimized, easy to copy utilitie functions.
- Extremely simple engine and event system for training & evaluating.
